==> babel-loader-9.1.3-x86_64-1cf.txz: install/doinst.sh <==
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf acorn )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../acorn/bin/acorn acorn )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf browserslist )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../browserslist/cli.js browserslist )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf jsesc )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../jsesc/bin/jsesc jsesc )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf json5 )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../json5/lib/cli.js json5 )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf parser )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../@babel/parser/bin/babel-parser.js parser )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf semver )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../@nicolo-ribaudo/semver-v6/bin/semver.js semver )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf terser )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../terser/bin/terser terser )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf update-browserslist-db )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../update-browserslist-db/cli.js update-browserslist-db )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf webpack )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../webpack/bin/webpack.js webpack )
( cd usr/lib64/node_modules/root/node_modules/.bin ; rm -rf network-address )
( cd usr/lib64/node_modules/root/node_modules/.bin ; ln -sf ../network-address/cli.js network-address )

==> babel-loader-10.0.0-x86_64-1cf.txz: install/doinst.sh <==
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf acorn )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../acorn/bin/acorn acorn )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf browserslist )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../browserslist/cli.js browserslist )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf jsesc )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../jsesc/bin/jsesc jsesc )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf json5 )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../json5/lib/cli.js json5 )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf parser )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../@babel/parser/bin/babel-parser.js parser )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf semver )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../semver/bin/semver.js semver )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf terser )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../terser/bin/terser terser )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf update-browserslist-db )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../update-browserslist-db/cli.js update-browserslist-db )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; rm -rf webpack )
( cd usr/lib64/node_modules/babel-loader/node_modules/.bin ; ln -sf ../webpack/bin/webpack.js webpack )
( cd usr/lib64/node_modules/root/node_modules/.bin ; rm -rf network-address )
( cd usr/lib64/node_modules/root/node_modules/.bin ; ln -sf ../network-address/cli.js network-address )
